@@ -2,8 +2,8 @@ import base64
 
 
 def base64_string(val):
-    if val is None:
-        return val
+    if val is None or val == b'':
+        return None
     return base64.b64encode(val).decode('utf-8')
 
 
